@@ -21,7 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifndef JPEGERRORMANAGER_H
 #define JPEGERRORMANAGER_H
 
-#include <setjmp.h>
+#include <csetjmp>
 
 extern "C" {
 #define XMD_H
