@@ -30,7 +30,6 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 
 namespace Gwenview
 {
-
 namespace ZoomMode
 {
 /**
@@ -39,7 +38,7 @@ namespace ZoomMode
 enum Enum {
     Autofit,
     KeepSame,
-    Individual
+    Individual,
 };
 
 } // namespace ZoomMode
